Installation — abexp 0.0.1 documentation

# Installation

## Latest release

This library is distributed on PyPI and can be installed with `pip`.

The latest release is version `0.0.1`.

    $ pip install abexp

The command above will automatically install all the dependencies listed in `requirements.txt`.

## Info for developers

The source code of the project is available on GitHub.

    $ git clone https://github.com/PlaytikaResearch/abexp.git

You can install the library and the dependencies from the source code with one of the following commands:

    $ pip install .                        # install library + dependencies
    $ pip install .[develop]               # install library + dependencies + developer-dependencies
    $ pip install -r requirements.txt      # install dependencies
    $ pip install -r requirements-dev.txt  # install dependencies + developer-dependencies

As suggested by the authors of `pymc3` and `pandoc`, we highly recommend to install these dependencies with `conda`:

    $ conda install -c conda-forge pandoc
    $ conda install -c conda-forge pymc3

To create the file `abexp.whl` for the installation with `pip` run the following command:

    $ python setup.py sdist bdist_wheel

To create the HTML documentation run the following commands:

    $ cd docs
    $ make html

## Run tests

Tests can be executed with `pytest` running the following commands:

    $ cd tests
    $ pytest                                      # run all tests
    $ pytest test_testmodule.py                   # run all tests within a module
    $ pytest test_testmodule.py -k test_testname  # run only 1 test